//============================================================
//http://OceanEyes.cnblogs.com
//============================================================

using System;
using System.Collections.Generic;
using System.Text;
using System.Data;
using System.Data.SqlClient;
using Insigma.ProjectQuote.Model;

namespace Insigma.ProjectQuote.DAL
{
	public partial class ProductService
	{
        public Product Add
			(Product product)
		{
				string sql ="INSERT INTO Product (ProductName, Specification, Manufacturer, Parameters, Price, Unit)  output inserted.ID VALUES (@ProductName, @Specification, @Manufacturer, @Parameters, @Price, @Unit)";
				SqlParameter[] para = new SqlParameter[]
					{
						new SqlParameter("@ProductName", ToDBValue(product.ProductName)),
						new SqlParameter("@Specification", ToDBValue(product.Specification)),
						new SqlParameter("@Manufacturer", ToDBValue(product.Manufacturer)),
						new SqlParameter("@Parameters", ToDBValue(product.Parameters)),
						new SqlParameter("@Price", ToDBValue(product.Price)),
						new SqlParameter("@Unit", ToDBValue(product.Unit)),
					};
					
				int newId = (int)SqlHelper.ExecuteScalar(sql, para);
				return GetByID(newId);
		}

        public int DeleteByID(int iD)
		{
            string sql = "DELETE Product WHERE ID = @ID";

           SqlParameter[] para = new SqlParameter[]
			{
				new SqlParameter("@ID", iD)
			};
		
            return SqlHelper.ExecuteNonQuery(sql, para);
		}
		
				
        public int Update(Product product)
        {
            string sql =
                "UPDATE Product " +
                "SET " +
			" ProductName = @ProductName" 
                +", Specification = @Specification" 
                +", Manufacturer = @Manufacturer" 
                +", Parameters = @Parameters" 
                +", Price = @Price" 
                +", Unit = @Unit" 
               
            +" WHERE ID = @ID";


			SqlParameter[] para = new SqlParameter[]
			{
				new SqlParameter("@ID", product.ID)
					,new SqlParameter("@ProductName", ToDBValue(product.ProductName))
					,new SqlParameter("@Specification", ToDBValue(product.Specification))
					,new SqlParameter("@Manufacturer", ToDBValue(product.Manufacturer))
					,new SqlParameter("@Parameters", ToDBValue(product.Parameters))
					,new SqlParameter("@Price", ToDBValue(product.Price))
					,new SqlParameter("@Unit", ToDBValue(product.Unit))
			};

			return SqlHelper.ExecuteNonQuery(sql, para);
        }		
		
        public Product GetByID(int iD)
        {
            string sql = "SELECT * FROM Product WHERE ID = @ID";
            using(SqlDataReader reader = SqlHelper.ExecuteDataReader(sql, new SqlParameter("@ID", iD)))
			{
				if (reader.Read())
				{
					return ToModel(reader);
				}
				else
				{
					return null;
				}
       		}
        }
		
		public Product ToModel(SqlDataReader reader)
		{
			Product product = new Product();

			product.ID = (int)ToModelValue(reader,"ID");
			product.ProductName = (string)ToModelValue(reader,"ProductName");
			product.Specification = (string)ToModelValue(reader,"Specification");
			product.Manufacturer = (string)ToModelValue(reader,"Manufacturer");
			product.Parameters = (string)ToModelValue(reader,"Parameters");
			product.Price = (decimal?)ToModelValue(reader,"Price");
			product.Unit = (string)ToModelValue(reader,"Unit");
			return product;
		}
		
		public int GetTotalCount()
		{
			string sql = "SELECT count(*) FROM Product";
			return (int)SqlHelper.ExecuteScalar(sql);
		}
		
		public IEnumerable<Product> GetPagedData(int minrownum,int maxrownum)
		{
			string sql = "SELECT * from(SELECT *,(row_number() over(order by ID))-1 rownum FROM Product) t where rownum>=@minrownum and rownum<=@maxrownum";
			using(SqlDataReader reader = SqlHelper.ExecuteDataReader(sql,
				new SqlParameter("@minrownum",minrownum),
				new SqlParameter("@maxrownum",maxrownum)))
			{
				return ToModels(reader);					
			}
		}
		
		public IEnumerable<Product> GetAll()
		{
			string sql = "SELECT * FROM Product";
			using(SqlDataReader reader = SqlHelper.ExecuteDataReader(sql))
			{
				return ToModels(reader);			
			}
		}
		
		protected IEnumerable<Product> ToModels(SqlDataReader reader)
		{
			var list = new List<Product>();
			while(reader.Read())
			{
				list.Add(ToModel(reader));
			}	
			return list;
		}		
		
		protected object ToDBValue(object value)
		{
			if(value==null)
			{
				return DBNull.Value;
			}
			else
			{
				return value;
			}
		}
		
		protected object ToModelValue(SqlDataReader reader,string columnName)
		{
			if(reader.IsDBNull(reader.GetOrdinal(columnName)))
			{
				return null;
			}
			else
			{
				return reader[columnName];
			}
		}
	}
}
