﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Data.SqlClient;
using Insigma.ProjectQuote.Model;

namespace Insigma.ProjectQuote.DAL
{
     public partial class ProjectItemService
    {
         public int UpdatePassChecked(ProjectItem projectItem)
         {
             string sql =
                 "UPDATE Project " +
                 "SET " +
             " ProjectName = @ProjectName"
                 + ", Customer = @Customer"
                 + ", Contact = @Contact"
                 + ", Tel = @Tel"
                 + ", DeliveryPlace = @DeliveryPlace"
                 + ", DeliveryTime = @DeliveryTime"
                 + ", TransportCosts = @TransportCosts"
                 + ", PaymentTerm = @PaymentTerm"
                 + ", Bak = @Bak"

             + " WHERE ID = @ID";


             SqlParameter[] para = new SqlParameter[]
			{
				new SqlParameter("@ID", projectItem._Project.ID)
					,new SqlParameter("@ProjectName", ToDBValue(projectItem._Project.ProjectName))
					,new SqlParameter("@Customer", ToDBValue(projectItem._Project.Customer))
					,new SqlParameter("@Contact", ToDBValue(projectItem._Project.Contact))
					,new SqlParameter("@Tel", ToDBValue(projectItem._Project.Tel))
					,new SqlParameter("@DeliveryPlace", ToDBValue(projectItem._Project.DeliveryPlace))
					,new SqlParameter("@DeliveryTime", ToDBValue(projectItem._Project.DeliveryTime))
					,new SqlParameter("@TransportCosts", ToDBValue(projectItem._Project.TransportCosts))
					,new SqlParameter("@PaymentTerm", ToDBValue(projectItem._Project.PaymentTerm))
					,new SqlParameter("@Bak", ToDBValue(projectItem._Project.Bak))
			};

             return SqlHelper.ExecuteNonQuery(sql, para);

         }
         public ProjectItem ToModelByForeignKey(SqlDataReader reader)
         {
             ProjectItem projectItem = new ProjectItem();
             projectItem._Project = new Project();

             projectItem._Project.ID = (int)ToModelValue(reader, "ID");
             projectItem._Project.Bak = ToModelValue(reader, "Bak").ToString();
             projectItem._Project.Contact = ToModelValue(reader, "Contact").ToString();
             projectItem._Project.Customer = ToModelValue(reader, "Customer").ToString();
             projectItem._Project.DeliveryPlace = ToModelValue(reader, "DeliveryPlace").ToString();
             projectItem._Project.DeliveryTime = ToModelValue(reader, "DeliveryTime").ToString();
             projectItem._Project.PaymentTerm = ToModelValue(reader, "PaymentTerm").ToString();
             projectItem._Project.ProjectName = ToModelValue(reader, "ProjectName").ToString();
             projectItem._Project.Tel = ToModelValue(reader, "Tel").ToString();
             projectItem._Project.TransportCosts = (decimal?)ToModelValue(reader, "TransportCosts");
            
             return projectItem;
         }
       

         public ProjectItem ToModelByFK(SqlDataReader reader)
         {
             ProjectItem projectItem = new ProjectItem();
             projectItem._Product = new Product();
             projectItem._Project = new Project();
             projectItem.ID = (int)ToModelValue(reader, "ID");
             projectItem._Product.ID = (int)ToModelValue(reader, "ProductID");
             projectItem._Project.ID = (int)ToModelValue(reader,"projectID");
             projectItem._Product.Manufacturer = ToModelValue(reader, "Manufacturer").ToString();
             projectItem._Product.Parameters = ToModelValue(reader, "Parameters").ToString();
             projectItem._Product.Price = decimal.Parse( ToModelValue(reader, "Price").ToString());
             projectItem._Product.ProductName = ToModelValue(reader, "ProductName").ToString();
             projectItem._Product.Specification = ToModelValue(reader, "Specification").ToString();
             projectItem._Product.Unit = ToModelValue(reader, "Unit").ToString();
             projectItem.Count = (int)ToModelValue(reader, "Count");
             projectItem.TotalMoney = (decimal)ToModelValue(reader, "TotalMoney");
             projectItem.UnitPrice = (decimal)ToModelValue(reader, "UnitPrice"); 
             return projectItem;
         }


         protected IEnumerable<ProjectItem> ToModelsByFK(SqlDataReader reader)
         {
             var list = new List<ProjectItem>();
             while (reader.Read())
             {
                 list.Add(ToModelByFK(reader));
             }
             return list;
         }	

         public IEnumerable<ProjectItem> GetAllProducts(int projectItemID)
         {
             string sql = @"SELECT  
             ProjectItem.[ID]
            ,[ProjectID]
           ,[ProductID]
           ,[UnitPrice]
           ,[Count]
           ,[TotalMoney] 
          ,[ProductName]
          ,[Specification]
          ,[Manufacturer]
          ,[Parameters]
          ,[Price]
          ,[Unit]   
          FROM ProjectItem,Product Where ProjectItem.ProductID=Product.ID and ProjectID=@ProjectID";
             using (SqlDataReader reader = SqlHelper.ExecuteDataReader(sql, new SqlParameter("ProjectID", projectItemID)))
             {
                 return ToModelsByFK(reader);
             }
         }

       
      


         public ProjectItem GetProjectByID(int id)
         {
             string sql = "SELECT * FROM Project WHERE  ID=@ID";
             using (SqlDataReader reader = SqlHelper.ExecuteDataReader(sql, new SqlParameter("@ID", id)))
             {
                 if (reader.Read())
                 {
                     return ToModelByForeignKey(reader);
                 }
                 else
                 {
                     return null;
                 }
             }
         }
         //根据ProjectID删除全部产品
         public int DeleteProjectItemsByProjectID(int projectID)
         {
             string sql = "DELETE ProjectItem WHERE ProjectID = @ProjectID";
             SqlParameter[] para = new SqlParameter[]
			{
				new SqlParameter("@ProjectID", projectID)
			};
             return SqlHelper.ExecuteNonQuery(sql, para);
		
         }
         //根据ProjectID得到TotalMoney
         public IEnumerable<Model.ProjectItem> GetProductTotalMoney(int projectID)
         {
             string sql = "select * from ProjectItem where ProjectID=@ProjectID";
			using(SqlDataReader reader = SqlHelper.ExecuteDataReader(sql,new SqlParameter("ProjectID",projectID)))
			{
				return ToModels(reader);			
			}
             
         }
         //
         public ProjectItem GetOneProjectItemByID(int ProjectItemID)
         {
            
             string sql = @"SELECT  
             ProjectItem.[ID]
            ,[ProjectID]
           ,[ProductID]
           ,[UnitPrice]
           ,[Count]
           ,[TotalMoney] 
          ,[ProductName]
          ,[Specification]
          ,[Manufacturer]
          ,[Parameters]
          ,[Price]
          ,[Unit]   
             
             FROM ProjectItem,Product WHERE ProjectItem.ProductID=Product.ID and ProjectItem.ID = @ID";
             using (SqlDataReader reader = SqlHelper.ExecuteDataReader(sql, new SqlParameter("@ID", ProjectItemID)))
             {
                 if (reader.Read())
                 {
                     return ToModelByFK(reader);
                 }
                 else
                 {
                     return null;
                 }
             }
         }



    }
}
